package com.lzmispt.data.resource.service.datasync.impl.handle;

package .tmp;

import com.lzmispt.data.center.entity.dto.databasestruct.DataSourceDTO;
import com.lzmispt.data.center.entity.vo.resource.datasource.DataSourceVO;
import com.lzmispt.data.resource.client.DataStandardClient;
import com.lzmispt.data.resource.entity.dto.datasync.GetDataSourceTableTreeDTO;
import com.lzmispt.data.resource.entity.vo.datasync.DataSourceTableTreeVO;
import com.lzmispt.data.resource.service.history.HistoryTableManager;
import com.lzmispt.dcbase.databasestruct.DataStructProvider;
import com.lzmispt.framework.entity.entity.ResultEntity;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;
import org.springframework.util.StringUtils;

@Repository
public abstract class AbstrcatDataSyncDatabase {
  @Autowired
  DataStandardClient dataStandardClient;
  
  @Autowired
  HistoryTableManager historyTableManager;
  
  private static final Map<Long, DataSourceVO> DATA_SOURCE_MAP = new HashMap<>();
  
  public DataStructProvider getDataStructProvider(Long dataSourceId, String platCode, String tokenId, String dataBaseName, String dbSchema) {
    DataSourceVO dataSource = DATA_SOURCE_MAP.get(dataSourceId);
    DataSourceDTO dataSourceDTO = new DataSourceDTO();
    BeanUtils.copyProperties(dataSource, dataSourceDTO);
    if (!StringUtils.isEmpty(dataBaseName))
      dataSourceDTO.setDbName(dataBaseName); 
    dataSourceDTO.setDbSchema(dbSchema);
    ResultEntity<DataStructProvider> getDataBaseProviderRet = DataStructProvider.getDataBaseProvider(dataSourceDTO);
    return (DataStructProvider)getDataBaseProviderRet.getObj();
  }
  
  public DataSourceTableTreeVO buildDataSourceTableVO(String dataBaseName, String schemaName, String tableName, Long dataSourceId, String type, Integer directoryType) {
    DataSourceTableTreeVO tableNode = new DataSourceTableTreeVO();
    if (dataBaseName != null) {
      String tableId, parentId;
      tableNode.setSourceDatabaseName(dataBaseName);
      tableNode.setDatabaseBaseType(type);
      tableNode.setDataSourceId(dataSourceId);
      tableNode.setChildNodes(new ArrayList());
      switch (directoryType.intValue()) {
        case 0:
          tableNode.setDirectoryName(dataBaseName);
          tableNode.setTableId(dataBaseName);
          tableNode.setParentId(null);
          break;
        case 1:
          tableNode.setDirectoryName(schemaName);
          tableNode.setTableId(dataBaseName + "." + schemaName);
          tableNode.setParentId(dataBaseName);
          break;
        case 2:
          tableNode.setDirectoryName(tableName);
          tableId = (schemaName != null) ? (schemaName + "." + tableName) : (dataBaseName + "." + tableName);
          parentId = (schemaName != null) ? (dataBaseName + "." + schemaName) : dataBaseName;
          tableNode.setTableId(tableId);
          tableNode.setParentId(parentId);
          break;
      } 
    } 
    tableNode.setDirectoryType(directoryType);
    tableNode.setSourceDatabaseSchema(schemaName);
    tableNode.setSourceTableName(tableName);
    return tableNode;
  }
  
  public void initDataSource(Long dataSourceId, String platCode, String tokenId) {
    ResultEntity<DataSourceVO> dataSourceResult = this.dataStandardClient.getPlaintextDataSourceById(dataSourceId, platCode, tokenId);
    DATA_SOURCE_MAP.put(dataSourceId, dataSourceResult.getObj());
  }
  
  public List<DataSourceTableTreeVO> getDataBaseList(GetDataSourceTableTreeDTO tableTreeDTO) {
    return getDataBaseList(tableTreeDTO.getDataSourceId(), tableTreeDTO.getPlatCode(), "0", tableTreeDTO.getIsEnableCdc());
  }
  
  public abstract List<DataSourceTableTreeVO> getDataBaseList(Long paramLong, String paramString1, String paramString2, Boolean paramBoolean);
  
  public abstract List<DataSourceTableTreeVO> getSchemaList(DataStructProvider paramDataStructProvider, Long paramLong, String paramString1, String paramString2, Boolean paramBoolean);
  
  public abstract List<DataSourceTableTreeVO> getTableList(DataStructProvider paramDataStructProvider, String paramString, Long paramLong);
  
  public abstract List<DataSourceTableTreeVO> getDataSourceTableTreeVO(Long paramLong, String paramString1, String paramString2) throws Exception;
}
